4.4.0 (2023-11-29)
==================
🎉 New features
--------------

- ensure we have the right version of logilab-database
- req: protect `find` of injection through `limit` parameter

👷 Bug fixes
-----------

- replace deprecated `rtype` by `relation_type`